@@ -100,7 +100,7 @@ def QuickML_Ensembling(X_train, y_train, X_test, y_test='', modeltype='Regressio
             estimators.append(('Boosting',model8, metrics4))
         estimators_list = [(tuples[0],tuples[1]) for tuples in estimators]
         estimator_names = [tuples[0] for tuples in estimators]
-        if verbose >= 2:
+        if verbose > 1:
             print('QuickML_Ensembling Model results:')
             print('    %s = %0.4f \n    %s = %0.4f\n    %s = %0.4f \n    %s = %0.4f' %(estimator_names[0], metrics1,
                     estimator_names[1], metrics2, estimator_names[2], metrics3, estimator_names[3], metrics4))
@@ -174,8 +174,10 @@ def QuickML_Ensembling(X_train, y_train, X_test, y_test='', modeltype='Regressio
             estimators.append(('Boosting',model8, metrics4))
         estimators_list = [(tuples[0],tuples[1]) for tuples in estimators]
         estimator_names = [tuples[0] for tuples in estimators]
+        if verbose > 0:
+            print('Estimators and Metrics: %s' %estimators)
         if not isinstance(y_test, str):
-            if verbose >= 2:
+            if verbose > 1:
                 print('QuickML_Ensembling Model results:')
                 print('    %s = %0.4f \n    %s = %0.4f\n    %s = %0.4f \n    %s = %0.4f' %(estimator_names[0], metrics1,
                         estimator_names[1], metrics2, estimator_names[2], metrics3, estimator_names[3], metrics4))
@@ -183,7 +185,7 @@ def QuickML_Ensembling(X_train, y_train, X_test, y_test='', modeltype='Regressio
             if verbose >= 1:
                 print('QuickML_Ensembling completed.')
     stacks = np.c_[results1,results2,results3,results4]
-    if verbose == 1:
+    if verbose > 0:
         print('    Time taken for Ensembling: %0.1f seconds' %(time.time()-start_time))
     return estimator_names, stacks
 #########################################################
\ No newline at end of file
